;; Generated package description from ibuffer-sidebar.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "ibuffer-sidebar" "0.0.1.0.20260612.36" "Sidebar for `ibuffer'" '((emacs "29.1")) :commit "1330b0f156e2275acd1a9256fc13a1d22e5e3a9e" :authors '(("James Nguyen" . "james@jojojames.com")) :maintainer '("James Nguyen" . "james@jojojames.com") :keywords '("ibuffer" "files" "tools") :url "https://github.com/jojojames/ibuffer-sidebar")
